"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.widthPercentageToDP = exports.width = exports.verticalDpiNormalizer = exports.modalTypes = exports.horizontalDpiNormalizer = exports.heightPercentageToDP = exports.height = exports.defaultVariant = exports.defaultSize = exports.colors = exports.Fonts = void 0;

var _reactNative = require("react-native");

const {
  width,
  height
} = _reactNative.Dimensions.get('window');

exports.height = height;
exports.width = width;
const testingHeight = 885.333333333;
const testingWidth = 411.428571428;

const verticalDpiNormalizer = dpi => {
  const multiplier = dpi / testingHeight;
  return height * multiplier;
};

exports.verticalDpiNormalizer = verticalDpiNormalizer;

const horizontalDpiNormalizer = dpi => {
  const multiplier = dpi / testingWidth;
  return width * multiplier;
};

exports.horizontalDpiNormalizer = horizontalDpiNormalizer;

const widthPercentageToDP = widthPercent => {
  const screenWidth = _reactNative.Dimensions.get('window').width; // Convert string input to decimal number


  const elemWidth = parseFloat(widthPercent);
  return _reactNative.PixelRatio.roundToNearestPixel(screenWidth * elemWidth / 100);
};

exports.widthPercentageToDP = widthPercentageToDP;

const heightPercentageToDP = heightPercent => {
  const screenHeight = _reactNative.Dimensions.get('window').height; // Convert string input to decimal number


  const elemHeight = parseFloat(heightPercent);
  return _reactNative.PixelRatio.roundToNearestPixel(screenHeight * elemHeight / 100);
};

exports.heightPercentageToDP = heightPercentageToDP;
const defaultVariant = ['black', 'blackItalic', 'bold', 'boldItalic', 'extraBold', 'extraBoldItalic', 'extraLight', 'extraLightItalic', 'light', 'lightItalic', 'mediumItalic', 'regular', 'semibold', 'italic', 'semiBoldItalic'];
exports.defaultVariant = defaultVariant;
const defaultSize = ['superSmall', 'extraSmall', 'small', 'medium', 'large', 'extraLarge', 'superLarge', 'Giant', 'superGiant'];
exports.defaultSize = defaultSize;
const modalTypes = {
  CENTER: 'MODAL_CENTER',
  BOTTOM: 'MODAL_BOTTOM',
  TOP: 'MODAL_TOP'
};
exports.modalTypes = modalTypes;
const colors = {
  primary: '#45ADA3',
  error: '#DF4A4A',
  warning: '#F2C94C',
  sec: {
    blue: '#6E89FA',
    green: '#37B64F',
    green2: '#27AAB6',
    green3: '#71BF5C',
    magenta: '#C18EFF',
    purple: '#8D64C0',
    yellow: '#FDB813',
    orange: '#F7931D',
    red: '#DF5648'
  },
  grey: {
    black: '#1C1D1D',
    grey: '#757575',
    grey1: '#E0E0E0',
    grey2: '#9B9B9B',
    grey3: '#C4C4C4',
    grey4: '#E5E5E5',
    grey5: '#F9F9F9',
    grey6: '#6A6A6A',
    grey7: '#CCCCCC',
    grey8: '#7A7A7A',
    grey9: '#E8E8E8',
    white: '#FFFFFF',
    darkGrey: '#333333',
    soft: '#E2E2E2'
  },
  trans: {
    red: 'rgba(195, 58, 44, 0.1)',
    black: 'rgba(0, 0, 0, 0.1)',
    orange: 'rgba(247, 147, 29, 0.25)',
    primary: 'rgba(236, 247,246, 1)',
    primary10: 'rgba(69, 173, 163, 0.1)'
  }
}; // TODO: update assets font

exports.colors = colors;
const Fonts = {
  superSmall: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '1%' : _reactNative.Platform.OS === 'android' ? '1.4%' : '1.2%')
  },
  extraSmall: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '1.2%' : _reactNative.Platform.OS === 'android' ? '1.6%' : '1.4%')
  },
  middleSmall: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '1.4%' : '1.6%')
  },
  small: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '1.4%' : _reactNative.Platform.OS === 'android' ? '1.8%' : '1.8%')
  },
  medium: {
    fontSize: heightPercentageToDP('2%')
  },
  large: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '1.9%' : _reactNative.Platform.OS === 'android' ? '2.2%' : '2.2%')
  },
  extraLarge: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '2.1%' : _reactNative.Platform.OS === 'android' ? '2.5%' : '2.4%')
  },
  superLarge: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '2.4%' : _reactNative.Platform.OS === 'android' ? '2.7%' : '2.6%')
  },
  Giant: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '2.6%' : _reactNative.Platform.OS === 'android' ? '2.9%' : '2.8%')
  },
  superGiant: {
    fontSize: heightPercentageToDP(_reactNative.Platform.isPad ? '3.5%' : _reactNative.Platform.OS === 'android' ? '3.8%' : '3.7%')
  },
  black: {
    fontFamily: 'Mulish-Black'
  },
  blackItalic: {
    fontFamily: 'Mulish-BlackItalic'
  },
  bold: {
    fontFamily: 'Mulish-Bold'
  },
  boldItalic: {
    fontFamily: 'Mulish-BoldItalic'
  },
  extraBold: {
    fontFamily: 'Mulish-ExtraBold'
  },
  extraBoldItalic: {
    fontFamily: 'Mulish-ExtraBoldItalic'
  },
  extraLight: {
    fontFamily: 'Mulish-ExtraLight'
  },
  extraLightItalic: {
    fontFamily: 'Mulish-ExtraLightItalic'
  },
  italic: {
    fontFamily: 'Mulish-Italic'
  },
  light: {
    fontFamily: 'Mulish-Light'
  },
  lightItalic: {
    fontFamily: 'Mulish-LightItalic'
  },
  mediumItalic: {
    fontFamily: 'Mulish-MediumItalic'
  },
  regular: {
    fontFamily: 'Mulish-Regular'
  },
  semiBold: {
    fontFamily: 'Mulish-SemiBold'
  },
  semiBoldItalic: {
    fontFamily: 'Mulish-SemiBoldItalic'
  }
};
exports.Fonts = Fonts;
//# sourceMappingURL=theme.js.map