import propTypes from 'prop-types';
import React from 'react';
import { ActivityIndicator, TouchableOpacity, View } from 'react-native';
import { colors, defaultSize, defaultVariant } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import styles from './button.style';

const GhostButton = _ref => {
  let {
    title,
    onPress,
    disabled,
    style,
    color,
    loading,
    left,
    leftIcon,
    iconSize,
    textColor,
    iconColor = colors.primary,
    rightIcon,
    textSize
  } = _ref;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPress,
    disabled: disabled,
    style: [styles.ghostButton, disabled && styles.disabled, {
      borderColor: disabled ? colors.grey.grey3 : color
    }, style]
  }, loading ? /*#__PURE__*/React.createElement(ActivityIndicator, {
    color: color
  }) : /*#__PURE__*/React.createElement(View, {
    style: styles.row
  }, left ? left : leftIcon ? /*#__PURE__*/React.createElement(View, {
    style: styles.leftIcon
  }, /*#__PURE__*/React.createElement(Icon, {
    size: iconSize,
    name: leftIcon,
    color: iconColor
  })) : null, /*#__PURE__*/React.createElement(Text, {
    adjustsFontSizeToFit: true,
    numberOfLines: 1,
    text: title,
    size: textSize,
    color: textColor,
    textStyle: {
      color: disabled ? colors.grey.grey3 : color
    },
    variant: "bold"
  }), rightIcon ? /*#__PURE__*/React.createElement(View, {
    style: styles.rightIcon
  }, /*#__PURE__*/React.createElement(Icon, {
    size: iconSize,
    name: rightIcon,
    color: iconColor
  })) : null));
};

GhostButton.propTypes = {
  left: propTypes.any,
  title: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
  size: propTypes.oneOf(defaultSize),
  variant: propTypes.oneOf(defaultVariant),
  onPress: propTypes.func.isRequired
};
GhostButton.defaultProps = {
  left: undefined,
  title: 'Button Title',
  textSize: 'medium',
  textVariant: 'medium',
  color: colors.primary,
  onPress: () => {}
};
export default /*#__PURE__*/React.memo(GhostButton);
//# sourceMappingURL=GhostButton.js.map