import React from 'react';
import { ActivityIndicator, Image, StyleSheet, TouchableOpacity, View } from 'react-native';
import { colors, width } from '../../../constant/theme';
import { formatMoney } from '../../../helpers';
import { Icon, Text } from '../../Atoms';
import { QtyButton } from '../Button';

const ItemCardCart = _ref => {
  let {
    loading,
    data,
    style,
    onQtyUpdate,
    onPressTrash
  } = _ref;
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.cardItem, style]
  }, loading ? /*#__PURE__*/React.createElement(View, {
    style: {
      width: '100%',
      marginBottom: width * 0.03
    }
  }, /*#__PURE__*/React.createElement(ActivityIndicator, {
    color: colors.primary
  })) : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Image, {
    source: {
      uri: data === null || data === void 0 ? void 0 : data.image_url
    },
    style: styles.imageStall
  }), /*#__PURE__*/React.createElement(View, {
    style: {
      width: '80%'
    }
  }, /*#__PURE__*/React.createElement(Text, {
    text: data === null || data === void 0 ? void 0 : data.name,
    variant: "bold",
    textStyle: {
      marginBottom: width * 0.01,
      width: '80%'
    },
    numberOfLines: 1,
    color: colors.grey.grey8
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.row
  }, /*#__PURE__*/React.createElement(Text, {
    text: formatMoney(data === null || data === void 0 ? void 0 : data.price),
    textStyle: {
      flex: 4
    }
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.rowItemDetail
  }, /*#__PURE__*/React.createElement(QtyButton, {
    initQty: data === null || data === void 0 ? void 0 : data.qty,
    onValueChange: onQtyUpdate
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.verticalLine
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPressTrash
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "trash-1",
    color: colors.error,
    size: 20
  })))))));
};

const styles = StyleSheet.create({
  cardItem: {
    margin: width * 0.05,
    padding: width * 0.03,
    paddingBottom: 0,
    backgroundColor: 'white',
    borderRadius: width * 0.02,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between'
  },
  imageStall: {
    width: width * 0.14,
    height: width * 0.14,
    aspectRatio: 1,
    borderRadius: width * 0.02
  },
  row: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  verticalLine: {
    borderLeftWidth: 1,
    borderLeftColor: colors.grey.soft,
    marginHorizontal: width * 0.01,
    width: 2,
    height: '50%'
  },
  rowItemDetail: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    flex: 6,
    paddingRight: width * 0.03,
    height: '100%'
  }
});
export default ItemCardCart;
//# sourceMappingURL=ItemCardCart.js.map