import { View, StyleSheet, Image, TouchableOpacity } from 'react-native';
import React from 'react';
import { colors, width } from '../../../constant/theme';
import { QtyButton } from '../Button';
import { Icon, Text } from '../../Atoms';
import { formatMoney } from '../../../helpers';

const ItemRowCart = _ref => {
  let {
    item,
    style,
    onQtyUpdate,
    onPressTrash,
    editable = true,
    isLastItem
  } = _ref;
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.productListItem, style]
  }, /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1.5
    }
  }, /*#__PURE__*/React.createElement(Image, {
    source: {
      uri: item === null || item === void 0 ? void 0 : item.image_url
    },
    style: styles.productListImage,
    resizeMode: "contain"
  })), /*#__PURE__*/React.createElement(View, {
    style: [styles.rightContentItem, isLastItem ? {} : styles.item]
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.productListData
  }, /*#__PURE__*/React.createElement(Text, {
    text: item === null || item === void 0 ? void 0 : item.item_name,
    color: colors.grey.grey8
  }), editable ? /*#__PURE__*/React.createElement(View, {
    style: styles.productListDataDetail
  }, /*#__PURE__*/React.createElement(QtyButton, {
    initQty: item === null || item === void 0 ? void 0 : item.qty,
    onValueChange: onQtyUpdate
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.verticalLine
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPressTrash
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "trash-1",
    color: colors.error,
    size: 20
  }))) : /*#__PURE__*/React.createElement(View, {
    style: styles.productListDataDetail
  }, /*#__PURE__*/React.createElement(Text, {
    text: `${item === null || item === void 0 ? void 0 : item.qty} produk`,
    textStyle: {
      paddingVertical: width * 0.04
    }
  }))), /*#__PURE__*/React.createElement(View, {
    style: styles.priceWrapper
  }, /*#__PURE__*/React.createElement(Text, {
    text: formatMoney(item === null || item === void 0 ? void 0 : item.price),
    textStyle: styles.itemPrice,
    variant: "bold",
    color: colors.grey.black
  }))));
};

const styles = StyleSheet.create({
  productListItem: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
    marginBottom: width * 0.03
  },
  productListImage: {
    width: width * 0.13,
    height: width * 0.13,
    aspectRatio: 1,
    borderRadius: width * 0.08
  },
  rightContentItem: {
    flex: 7,
    flexDirection: 'row',
    justifyContent: 'space-between'
  },
  item: {
    borderBottomWidth: 0.5,
    borderBottomColor: colors.grey.grey8
  },
  productListData: {
    flex: 6,
    paddingHorizontal: width * 0.03
  },
  productListDataDetail: {
    width: '80%',
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginTop: width * 0.01
  },
  priceWrapper: {
    flex: 2,
    alignItems: 'flex-end',
    justifyContent: 'flex-end'
  },
  verticalLine: {
    borderLeftWidth: 1,
    borderLeftColor: colors.grey.soft,
    marginHorizontal: width * 0.01,
    width: 1,
    height: '50%'
  },
  itemPrice: {
    textAlign: 'center',
    textAlignVertical: 'bottom',
    paddingBottom: width * 0.04
  }
});
export default ItemRowCart;
//# sourceMappingURL=ItemRowCart.js.map