function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import moment from 'moment-timezone';
import 'moment/locale/id';
import propTypes from 'prop-types';
import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { ActivityIndicator, Pressable, TextInput, View } from 'react-native';
import DateTimePickerModal from 'react-native-modal-datetime-picker';
import { colors, Fonts, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import { styles } from './input.style';
const inputType = ['email', 'phonenumber', 'datepicker', 'dropdown', 'default'];
const StackedLabelInput = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    label,
    labelSize,
    labelColor,
    value,
    keyboardType,
    containerStyle,
    inputStyle,
    invalidInput,
    invalidMsg,
    optional,
    required,
    secureTextEntry,
    type,
    disabled,
    right,
    placeholder,
    onDateChange,
    onPress,
    isLoading,
    onClearText,
    ...props
  } = _ref;
  useImperativeHandle(ref, () => ({
    showDatePicker: _showDatePicker,
    closeDatePicker: _closeDatePicker
  }));
  const [showEntry, setShowEntry] = useState(secureTextEntry);
  const [showPicker, setShowPicker] = useState(false);
  const [tempSelectDate, setTempSelectDate] = useState({
    date: '',
    formattedDate: ''
  });

  function _showDatePicker() {
    setShowPicker(true);
  }

  function _closeDatePicker() {
    setShowPicker(false);
  }

  const RenderChildren = () => {
    let Child = null;
    let Main = /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
      placeholder: placeholder,
      style: [Fonts.regular, Fonts.small, styles.formInput, {
        width: right ? '90%' : '100%'
      }, inputStyle],
      value: value,
      secureTextEntry: showEntry,
      keyboardType: keyboardType,
      underlineColorAndroid: "transparent"
    })); //   if (secureTextEntry) {
    //     Child = (
    //       <Pressable
    //         disabled={disabled}
    //         onPress={() => setShowEntry(!showEntry)}
    //         style={{ width: width * 0.07 }}
    //       >
    //         <Icon
    //           name={showEntry ? "eye-off" : "eye"}
    //           type="ionicons"
    //           style={styles.childIcon}
    //         />
    //       </Pressable>
    //     );
    //   } else

    if (onClearText) {
      Child = /*#__PURE__*/React.createElement(Pressable, {
        disabled: disabled,
        onPress: onClearText,
        style: {
          width: width * 0.07
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        name: 'close',
        color: invalidInput ? colors.grey.grey9 : colors.grey.grey8,
        size: 15
      }));
    }

    if (type === inputType[0]) {
      //email
      if (value.length < 2 && !invalidInput) {
        Child = null;
      } else {
        Main = /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
          style: [Fonts.regular, Fonts.small, styles.formInput, {
            width: right ? '90%' : '100%'
          }, inputStyle],
          placeholder: placeholder,
          value: value,
          secureTextEntry: showEntry,
          keyboardType: "email-address",
          autoCapitalize: "none",
          autoCorrect: false,
          underlineColorAndroid: "transparent"
        })); //   Child = (
        //     <Icon
        //       name={invalidInput ? 'close-circle' : 'check_icon_filled'}
        //       color={invalidInput ? colors.error : colors.sec.green}
        //       size={15}
        //     />
        //   );
      }
    } else if (type === inputType[1]) {
      //phonenumber
      Main = /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
        placeholder: placeholder,
        style: [Fonts.regular, Fonts.small, styles.formInput, {
          width: right ? '90%' : '100%'
        }, inputStyle],
        value: value,
        secureTextEntry: showEntry,
        keyboardType: "phone-pad",
        underlineColorAndroid: "transparent"
      }));
    } //   else if (type === inputType[2]) {
    //     //datepicker
    //     let inputValue = '';
    //     if (value) {
    //       inputValue = value;
    //     } else if (!value) {
    //       if (tempSelectDate.formattedDate) {
    //         inputValue = tempSelectDate.formattedDate;
    //       } else {
    //         inputValue = placeholder;
    //       }
    //     }
    //     Main = (
    //       <Text
    //         text={inputValue}
    //         color={
    //           tempSelectDate.formattedDate
    //             ? colors.grey.black
    //             : colors.grey.grey3
    //         }
    //         textStyle={[styles.formInput]}
    //       />
    //     );
    //     Child = (
    //       <Pressable
    //         disabled={disabled}
    //         onPress={_showDatePicker}
    //         style={{ width: width * 0.07 }}
    //       >
    //         <Icon name={'calendar'} color={colors.grey.grey2} size={15} />
    //       </Pressable>
    //     );
    //   }
    //    else if (type === inputType[3]) {
    //     //dropdown
    //     Main = (
    //       <Text
    //         text={value ? value : placeholder}
    //         color={value ? colors.grey.black : colors.grey.grey3}
    //         textStyle={[styles.formInput]}
    //       />
    //     );
    //     Child = (
    //       <Pressable disabled={disabled} style={{ width: width * 0.07 }}>
    //         <Icon
    //           name={'back_down-frame'}
    //           color={colors.grey.grey2}
    //           size={15}
    //         />
    //       </Pressable>
    //     );
    //   }


    return /*#__PURE__*/React.createElement(View, {
      style: styles.content
    }, Main, isLoading ? /*#__PURE__*/React.createElement(ActivityIndicator, {
      size: 'small',
      color: colors.primary
    }) : Child);
  };

  return /*#__PURE__*/React.createElement(View, {
    style: [styles.container, containerStyle]
  }, label ? /*#__PURE__*/React.createElement(View, {
    style: styles.labelWrapper
  }, /*#__PURE__*/React.createElement(Text, {
    text: label,
    size: labelSize ? labelSize : 'large' //   variant="bold"
    ,
    textStyle: {
      color: labelColor ? labelColor : colors.grey.grey8
    }
  }), required ? /*#__PURE__*/React.createElement(Text, {
    text: "*",
    color: colors.primary
  }) : null, optional ? /*#__PURE__*/React.createElement(Text, {
    text: "(Opsional)",
    textStyle: {
      marginLeft: width * 0.02
    }
  }) : null) : null, /*#__PURE__*/React.createElement(Pressable, {
    disabled: isLoading,
    onPress: onPress,
    style: styles.formInputContainer
  }, RenderChildren(), /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
    clearButtonMode: "always",
    placeholder: placeholder,
    style: [Fonts.regular, Fonts.medium, styles.formInput, {
      width: right ? '90%' : '100%'
    }, inputStyle],
    value: value,
    secureTextEntry: showEntry,
    keyboardType: keyboardType,
    underlineColorAndroid: "transparent"
  }))), invalidInput && type !== 'email' && /*#__PURE__*/React.createElement(Text, {
    text: invalidMsg ? invalidMsg : `${label} tidak boleh kosong`,
    size: "small",
    color: colors.error
  }), /*#__PURE__*/React.createElement(DateTimePickerModal, {
    isVisible: showPicker,
    date: tempSelectDate.date ? new Date(tempSelectDate.date) : new Date(),
    mode: "date",
    maximumDate: new Date(),
    onConfirm: date => {
      setShowPicker(false);
      onDateChange(moment(date).format('DD-MM-YYYY'));
      setTempSelectDate({
        date: date,
        formattedDate: moment(date).format('DD-MM-YYYY')
      });
    },
    onCancel: () => {
      setShowPicker(false);
    }
  }));
});
StackedLabelInput.propTypes = {
  label: propTypes.string,
  containerStyle: propTypes.oneOfType([propTypes.object, propTypes.array]),
  type: propTypes.oneOf(inputType),
  inputStyle: propTypes.oneOfType([propTypes.object, propTypes.array]),
  invalidInput: propTypes.bool
};
StackedLabelInput.defaultProps = {
  containerStyle: {},
  inputStyle: {},
  keyboardType: 'default',
  value: '',
  invalidInput: false,
  type: 'default'
};
export default StackedLabelInput;
//# sourceMappingURL=StackedLabelInput.js.map