import React, { useCallback, useRef, useState } from 'react';
import { Platform, ScrollView, Vibration, View } from 'react-native';
import { width } from '../../../constant/theme';
import CarouselItem from './CarouselItem';
import { styles } from './slider.style'; // TODO: implement auto play interval

const Carousel = _ref => {
  let {
    data = [],
    vibrate = false,
    style,
    wrapperStyle
  } = _ref;
  const ITEM_WIDTH = width * 0.85;
  const scrollRef = useRef(null);
  const [timer, setTimer] = useState(null);
  const [momentumStarted, setMomentumStarted] = useState(false);
  const [isScrollTo, setIsScrollTo] = useState(false);
  const [dragStarted, setDragStarted] = useState(false);

  const onMomentumScrollBegin = () => {
    setMomentumStarted(true);
    timer && clearTimeout(timer);
  };

  const onScrollEndDrag = e => {
    setDragStarted(false);
    const _e = { ...e
    };
    timer && clearTimeout(timer);
    setTimer(setTimeout(() => {
      if (!momentumStarted) {
        scrollFix(_e);
      }
    }, 50));
  };

  const onMomentumScrollEnd = e => {
    setMomentumStarted(false);

    if (!isScrollTo && !dragStarted) {
      scrollFix(e);
    }
  };

  const onScrollBeginDrag = () => {
    setDragStarted(true);

    if (Platform.OS === 'ios') {
      setIsScrollTo(false);
    }

    timer && clearTimeout(timer);
  };

  const scrollFix = useCallback(e => {
    var _e$nativeEvent;

    let x = 0;
    const w = ITEM_WIDTH;
    const extraMargin = width * 0.05;

    if (e !== null && e !== void 0 && (_e$nativeEvent = e.nativeEvent) !== null && _e$nativeEvent !== void 0 && _e$nativeEvent.contentOffset) {
      var _e$nativeEvent2, _e$nativeEvent2$conte;

      x = e === null || e === void 0 ? void 0 : (_e$nativeEvent2 = e.nativeEvent) === null || _e$nativeEvent2 === void 0 ? void 0 : (_e$nativeEvent2$conte = _e$nativeEvent2.contentOffset) === null || _e$nativeEvent2$conte === void 0 ? void 0 : _e$nativeEvent2$conte.x;
    }

    const selectedIdx = Math.round(x / w);

    const _x = selectedIdx * w;

    if (_x !== x) {
      var _scrollRef$current;

      if (Platform.OS === 'ios') {
        setIsScrollTo(true);
      }

      scrollRef === null || scrollRef === void 0 ? void 0 : (_scrollRef$current = scrollRef.current) === null || _scrollRef$current === void 0 ? void 0 : _scrollRef$current.scrollTo({
        x: _x + extraMargin
      });
      vibrate && Vibration.vibrate(50);
    }
  }, []);

  if (data.length) {
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.sliderWrapper, wrapperStyle]
    }, /*#__PURE__*/React.createElement(ScrollView, {
      ref: scrollRef,
      horizontal: true,
      showsHorizontalScrollIndicator: false,
      style: style,
      bounces: false,
      onMomentumScrollBegin: _e => onMomentumScrollBegin(),
      onMomentumScrollEnd: e => onMomentumScrollEnd(e),
      onScrollBeginDrag: _e => onScrollBeginDrag(),
      onScrollEndDrag: e => onScrollEndDrag(e)
    }, data === null || data === void 0 ? void 0 : data.slice(0, 5).map((item, index) => {
      return /*#__PURE__*/React.createElement(CarouselItem, {
        key: index.toString(),
        item: item
      });
    })));
  } else {
    return null;
  }
};

export default Carousel;
//# sourceMappingURL=Carousel.js.map