import React, { useCallback, useRef, useState } from 'react';
import { Image, Platform, ScrollView, TouchableOpacity, View } from 'react-native';
import { height, width } from '../../../constant/theme';
import { ImageViewer } from '../../Molecules';

const SliderItem = _ref => {
  let {
    item,
    onPress
  } = _ref;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPress,
    activeOpacity: 0.8,
    style: {
      width: width,
      height: height * 0.35
    }
  }, /*#__PURE__*/React.createElement(Image, {
    source: item === null || item === void 0 ? void 0 : item.image,
    resizeMode: "cover",
    resizeMethod: "auto",
    style: {
      width: '100%',
      height: '100%'
    }
  }));
};

const SliderImage = _ref2 => {
  let {
    data = [],
    style,
    itemWidth
  } = _ref2;
  const ITEM_WIDTH = width || itemWidth;
  const scrollRef = useRef(null);
  const [timer, setTimer] = useState(null);
  const [momentumStarted, setMomentumStarted] = useState(false);
  const [isScrollTo, setIsScrollTo] = useState(false);
  const [dragStarted, setDragStarted] = useState(false);
  const [imageData, setImageData] = useState({
    isVisible: false,
    image: null
  });

  const onMomentumScrollBegin = () => {
    setMomentumStarted(true);
    timer && clearTimeout(timer);
  };

  const onScrollEndDrag = e => {
    setDragStarted(false);
    const _e = { ...e
    };
    timer && clearTimeout(timer);
    setTimer(setTimeout(() => {
      if (!momentumStarted) {
        scrollFix(_e);
      }
    }, 50));
  };

  const onMomentumScrollEnd = e => {
    setMomentumStarted(false);

    if (!isScrollTo && !dragStarted) {
      scrollFix(e);
    }
  };

  const onScrollBeginDrag = () => {
    setDragStarted(true);

    if (Platform.OS === 'ios') {
      setIsScrollTo(false);
    }

    timer && clearTimeout(timer);
  };

  const scrollFix = useCallback(e => {
    var _e$nativeEvent;

    let x = 0;
    const w = ITEM_WIDTH;

    if (e !== null && e !== void 0 && (_e$nativeEvent = e.nativeEvent) !== null && _e$nativeEvent !== void 0 && _e$nativeEvent.contentOffset) {
      var _e$nativeEvent2, _e$nativeEvent2$conte;

      x = e === null || e === void 0 ? void 0 : (_e$nativeEvent2 = e.nativeEvent) === null || _e$nativeEvent2 === void 0 ? void 0 : (_e$nativeEvent2$conte = _e$nativeEvent2.contentOffset) === null || _e$nativeEvent2$conte === void 0 ? void 0 : _e$nativeEvent2$conte.x;
    }

    const selectedIdx = Math.round(x / w);

    const _x = selectedIdx * w;

    if (_x !== x) {
      var _scrollRef$current;

      if (Platform.OS === 'ios') {
        setIsScrollTo(true);
      }

      scrollRef === null || scrollRef === void 0 ? void 0 : (_scrollRef$current = scrollRef.current) === null || _scrollRef$current === void 0 ? void 0 : _scrollRef$current.scrollTo({
        x: _x
      });
    }
  }, []);
  return /*#__PURE__*/React.createElement(View, {
    style: [{
      width,
      height: height * 0.35
    }, style]
  }, /*#__PURE__*/React.createElement(ScrollView, {
    ref: scrollRef,
    horizontal: true,
    showsHorizontalScrollIndicator: false,
    style: style,
    bounces: false,
    onMomentumScrollBegin: _e => onMomentumScrollBegin(),
    onMomentumScrollEnd: e => onMomentumScrollEnd(e),
    onScrollBeginDrag: _e => onScrollBeginDrag(),
    onScrollEndDrag: e => onScrollEndDrag(e)
  }, data === null || data === void 0 ? void 0 : data.map((item, index) => {
    return /*#__PURE__*/React.createElement(SliderItem, {
      key: index,
      onPress: () => _showImage(item),
      item: item
    });
  })), /*#__PURE__*/React.createElement(ImageViewer, {
    isVisible: imageData === null || imageData === void 0 ? void 0 : imageData.isVisible,
    image: imageData === null || imageData === void 0 ? void 0 : imageData.image,
    onBackdropPress: _closeModal,
    onBackButtonPress: _closeModal,
    onPress: _closeModal
  }));

  function _showImage(item) {
    setImageData({
      isVisible: true,
      image: item === null || item === void 0 ? void 0 : item.image
    });
  }

  function _closeModal() {
    setImageData({
      isVisible: false,
      image: null
    });
  }
};

export default SliderImage;
//# sourceMappingURL=SliderImage.js.map