import propTypes from 'prop-types';
import React, { Component } from 'react';
import { StyleSheet, View } from 'react-native';
import { colors, width } from '../../constant/theme';
import { ButtonText } from '../Molecules';
import Text from './Text';

function toHHMMSS(sec) {
  var sec_num = parseInt(sec, 10); // don't forget the second param
  var hours = Math.floor(sec_num / 3600);
  var minutes = Math.floor((sec_num - hours * 3600) / 60);
  var seconds = sec_num - hours * 3600 - minutes * 60;

  if (hours < 10) {
    hours = '0' + hours;
  }
  if (minutes < 10) {
    minutes = '0' + minutes;
  }
  if (seconds < 10) {
    seconds = '0' + seconds;
  }
  return minutes + ':' + seconds;
}

class CountdownComponent extends Component {
  constructor(props) {
    super(props);
    this.state = {
      timer: 60, // 1 mins
    };
  }

  componentDidMount() {
    this.startTimer();
  }

  componentWillUnmount() {
    clearInterval(this.clockCall);
  }

  decrementClock = () => {
    if (this.state.timer === 0) {
      clearInterval(this.clockCall);
    }
    this.setState((prevstate) => ({
      timer: prevstate.timer === 0 ? prevstate.timer - 0 : prevstate.timer - 1,
    }));
  };

  startTimer = () => {
    this.setState({
      timer: 60 * this.props.minutes,
    });

    this.clockCall = setInterval(() => {
      this.decrementClock();
    }, 1000);
  };

  onRestart = () => {
    this.startTimer();
    this.props.onFinish && this.props.onFinish();
  };

  render() {
    return (
      <>
        {this.state.timer === 0 ? (
          <ButtonText
            onPress={this.onRestart}
            title={this.props.resendTitle}
            textColor={this.props.buttonResendColor}
            textVariant={'extraBold'}
          />
        ) : (
          <View style={styles.wrapper}>
            <Text
              text={toHHMMSS(this.state.timer)}
              textVariant={'extraBold'}
              color={this.props.buttonResendColor}
            />
          </View>
        )}
      </>
    );
  }
}

const styles = StyleSheet.create({
  wrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'flex-start',
    marginVertical: width * 0.05,
    padding: width * 0.03,
  },
  btnText: {
    marginLeft: width * 0.03,
    color: colors.sec.blue,
  },
});

CountdownComponent.propTypes = {
  onFinish: propTypes.func,
  resendTitle: propTypes.string,
  minutes: propTypes.number,
  buttonResendColor: propTypes.string,
};

CountdownComponent.defaultProps = {
  onFinish: () => {},
  resendTitle: 'Kirim Ulang OTP',
  buttonResendColor: colors.grey.black,
  minutes: 1,
};

export default CountdownComponent;
