import propTypes from 'prop-types';
import React from 'react';
import { ActivityIndicator, TouchableOpacity, View } from 'react-native';
import { colors, defaultSize, defaultVariant } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import styles from './button.style';

const Button = ({
  title,
  onPress,
  disabled,
  style,
  loading,
  textColor,
  textSize,
  textStyle,
  leftIcon,
  rightIcon,
  iconColor = 'white',
  iconSize = 20,
}) => {
  return (
    <TouchableOpacity
      onPress={onPress}
      disabled={disabled}
      style={[
        styles.buttonDefault,
        disabled && { backgroundColor: colors.grey.grey9 },
        style,
      ]}
    >
      {loading ? (
        <ActivityIndicator color={textColor} size="small" />
      ) : (
        <View style={styles.row}>
          {leftIcon ? (
            <View style={styles.leftIcon}>
              <Icon size={iconSize} name={leftIcon} color={iconColor} />
            </View>
          ) : null}
          <Text
            adjustsFontSizeToFit
            numberOfLines={1}
            text={title}
            size={textSize}
            color={textColor}
            variant="bold"
            textStyle={textStyle}
          />
          {rightIcon ? (
            <View style={styles.rightIcon}>
              <Icon size={iconSize} name={rightIcon} color={iconColor} />
            </View>
          ) : null}
        </View>
      )}
    </TouchableOpacity>
  );
};

Button.propTypes = {
  title: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
  size: propTypes.oneOf(defaultSize),
  variant: propTypes.oneOf(defaultVariant),
  onPress: propTypes.func.isRequired,
};

Button.defaultProps = {
  title: 'Button Title',
  textSize: 'medium',
  textVariant: 'medium',
  color: colors.primary,
  textColor: colors.grey.white,
  onPress: () => {},
};

export default React.memo(Button);
