import propTypes from 'prop-types';
import React from 'react';
import { TouchableOpacity } from 'react-native';
import { colors, defaultSize, defaultVariant } from '../../../constant/theme';
import { Text } from '../../Atoms';
import styles from './button.style';

const ButtonText = ({
  title,
  textSize,
  textVariant,
  textColor,
  style,
  onPress,
}) => {
  return (
    <TouchableOpacity onPress={onPress} style={[styles.buttonText, style]}>
      <Text
        text={title}
        size={textSize}
        variant={textVariant}
        color={textColor}
      />
    </TouchableOpacity>
  );
};

ButtonText.propTypes = {
  title: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
  size: propTypes.oneOf(defaultSize),
  variant: propTypes.oneOf(defaultVariant),
  onPress: propTypes.func.isRequired,
};

ButtonText.defaultProps = {
  title: 'Title',
  textSize: 'medium',
  textVariant: 'bold',
  textColor: colors.primary,
  onPress: () => {},
};

export default React.memo(ButtonText);
