import propTypes from 'prop-types';
import React from 'react';
import { ActivityIndicator, TouchableOpacity, View } from 'react-native';
import { colors, defaultSize, defaultVariant } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import styles from './button.style';

const GhostButton = ({
  title,
  onPress,
  disabled,
  style,
  color,
  loading,
  left,
  leftIcon,
  iconSize,
  textColor,
  iconColor = colors.primary,
  rightIcon,
  textSize,
}) => {
  return (
    <TouchableOpacity
      onPress={onPress}
      disabled={disabled}
      style={[
        styles.ghostButton,
        disabled && styles.disabled,
        { borderColor: disabled ? colors.grey.grey3 : color },
        style,
      ]}
    >
      {loading ? (
        <ActivityIndicator color={color} />
      ) : (
        <View style={styles.row}>
          {left ? (
            left
          ) : leftIcon ? (
            <View style={styles.leftIcon}>
              <Icon size={iconSize} name={leftIcon} color={iconColor} />
            </View>
          ) : null}
          <Text
            adjustsFontSizeToFit
            numberOfLines={1}
            text={title}
            size={textSize}
            color={textColor}
            textStyle={{ color: disabled ? colors.grey.grey3 : color }}
            variant="bold"
          />
          {rightIcon ? (
            <View style={styles.rightIcon}>
              <Icon size={iconSize} name={rightIcon} color={iconColor} />
            </View>
          ) : null}
        </View>
      )}
    </TouchableOpacity>
  );
};

GhostButton.propTypes = {
  left: propTypes.any,
  title: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
  size: propTypes.oneOf(defaultSize),
  variant: propTypes.oneOf(defaultVariant),
  onPress: propTypes.func.isRequired,
};

GhostButton.defaultProps = {
  left: undefined,
  title: 'Button Title',
  textSize: 'medium',
  textVariant: 'medium',
  color: colors.primary,
  onPress: () => {},
};

export default React.memo(GhostButton);
