import React, { useEffect, useMemo, useState } from 'react';
import { StyleSheet, TextInput, View } from 'react-native';
import { ButtonIcon } from '..';
import { colors, width } from '../../../constant/theme';
import { Text } from '../../Atoms';

const QtyButton = ({ inputable, onValueChange, initQty, inputAble }) => {
  const [qty, setQty] = useState(1);

  useEffect(() => {
    if (initQty) {
      setQty(initQty);
    }
  }, [initQty]);

  useEffect(() => {
    onValueChange ? onValueChange(qty) : null;
  }, [qty]);

  const onPressMinus = () => {
    if (qty === 0) {
      setQty(0);
    } else {
      setQty(qty - 1);
    }
  };

  const onPressPlus = () => {
    setQty(qty + 1);
  };

  if (inputAble) {
    const Content = useMemo(() => {
      return (
        <View style={stylesInputable.rowAlignCenter}>
          <ButtonIcon
            onPress={onPressMinus}
            iconName="minus"
            style={stylesInputable.buttonItem}
            iconSize={23}
            iconColor={colors.primary}
          />
          <TextInput
            style={stylesInputable.input}
            value={qty.toString()}
            defaultValue={initQty.toString()}
            onChangeText={(val) => {
              setQty(val);
            }}
            keyboardType="number-pad"
          />
          <ButtonIcon
            onPress={onPressPlus}
            iconName="plus"
            style={stylesInputable.buttonItem}
            iconSize={20}
            iconColor={colors.primary}
          />
        </View>
      );
    }, [qty]);

    return Content;
  } else {
    return (
      <View style={styles.rowAlignCenter}>
        <ButtonIcon
          onPress={onPressMinus}
          iconName="minus"
          style={styles.buttonItem}
          iconSize={15}
          iconColor={colors.primary}
        />
        <View style={styles.qtyVal}>
          {inputable ? null : <Text text={qty} />}
        </View>
        <ButtonIcon
          onPress={onPressPlus}
          iconName="plus"
          style={styles.buttonItem}
          iconSize={15}
          iconColor={colors.primary}
        />
      </View>
    );
  }
};

const styles = StyleSheet.create({
  rowAlignCenter: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingVertical: width * 0.03,
  },
  qtyVal: {
    marginHorizontal: width * 0.05,
  },
  buttonItem: {
    padding: width * 0.01,
    backgroundColor: 'white',
    borderWidth: 1,
    borderColor: colors.primary,
    width: width * 0.07,
    height: width * 0.07,
    borderRadius: (width * 0.07) / 2,
  },
});

const stylesInputable = StyleSheet.create({
  rowAlignCenter: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingVertical: width * 0.03,
  },
  input: {
    borderRadius: 12,
    borderWidth: 1,
    borderColor: colors.grey.grey7,
    padding: width * 0.01,
    paddingVertical: 0,
    textAlign: 'center',
    marginHorizontal: width * 0.02,
  },
  buttonItem: {
    padding: width * 0.01,
    backgroundColor: 'white',
    width: width * 0.07,
    height: width * 0.07,
  },
});

export default QtyButton;
