import React from 'react';
import {
  ActivityIndicator,
  Image,
  StyleSheet,
  TouchableOpacity,
  View,
} from 'react-native';
import { colors, width } from '../../../constant/theme';
import { formatMoney } from '../../../helpers';
import { Icon, Text } from '../../Atoms';
import { QtyButton } from '../Button';

const ItemCardCart = ({ loading, data, style, onQtyUpdate, onPressTrash }) => {
  return (
    <View style={[styles.cardItem, style]}>
      {loading ? (
        <View style={{ width: '100%', marginBottom: width * 0.03 }}>
          <ActivityIndicator color={colors.primary} />
        </View>
      ) : (
        <>
          <Image source={{ uri: data?.image_url }} style={styles.imageStall} />
          <View style={{ width: '80%' }}>
            <Text
              text={data?.name}
              variant="bold"
              textStyle={{ marginBottom: width * 0.01, width: '80%' }}
              numberOfLines={1}
              color={colors.grey.grey8}
            />
            <View style={styles.row}>
              <Text text={formatMoney(data?.price)} textStyle={{ flex: 4 }} />
              <View style={styles.rowItemDetail}>
                <QtyButton initQty={data?.qty} onValueChange={onQtyUpdate} />
                <View style={styles.verticalLine} />
                <TouchableOpacity onPress={onPressTrash}>
                  <Icon name="trash-1" color={colors.error} size={20} />
                </TouchableOpacity>
              </View>
            </View>
          </View>
        </>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  cardItem: {
    margin: width * 0.05,
    padding: width * 0.03,
    paddingBottom: 0,
    backgroundColor: 'white',
    borderRadius: width * 0.02,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
  },
  imageStall: {
    width: width * 0.14,
    height: width * 0.14,
    aspectRatio: 1,
    borderRadius: width * 0.02,
  },
  row: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  verticalLine: {
    borderLeftWidth: 1,
    borderLeftColor: colors.grey.soft,
    marginHorizontal: width * 0.01,
    width: 2,
    height: '50%',
  },
  rowItemDetail: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    flex: 6,
    paddingRight: width * 0.03,
    height: '100%',
  },
});

export default ItemCardCart;
