import moment from 'moment-timezone';
import 'moment/locale/id';
import React from 'react';
import { Image, StyleSheet, TouchableOpacity, View } from 'react-native';
import { Icons } from '../../../assets/icons';
import { colors, width } from '../../../constant/theme';
import { formatMoney } from '../../../helpers';
import { Text } from '../../Atoms';

const defaultIcon = Icons.bagPrimary;

const OrderItem = ({ data, imageIcon, style, onPress }) => {
  const formattedDate = data?.orderDate
    ? `${moment(data?.orderDate).format('LL')}, ${moment(
        data?.orderDate
      ).format('LT')}`
    : '';
  const item = data?.items[0];
  const renderName =
    data?.items?.length > 1
      ? `${item?.name} + ${data?.items?.length - 1} Lainnya`
      : item?.name;

  return (
    <TouchableOpacity
      activeOpacity={0.8}
      onPress={onPress}
      style={[styles.cardWrapper, style]}
    >
      {/* HEADER */}
      <View style={styles.header}>
        <View style={styles.flex1}>
          <Image
            source={imageIcon ? imageIcon : defaultIcon}
            style={styles.headIcon}
            resizeMode="contain"
          />
        </View>
        <View style={styles.headBody}>
          <Text text={data?.number} variant="bold" />
          <Text text={formattedDate} variant="light" />
        </View>
      </View>
      {/* -- END Header */}
      {/* Body */}
      <View style={styles.body}>
        <View style={{ flex: 2 }}>
          <Image
            source={item ? { uri: item.image_url } : {}}
            style={styles.itemImage}
            resizeMode="contain"
          />
        </View>
        <View style={{ flex: 8, paddingLeft: width * 0.03 }}>
          <View style={{ alignItems: 'flex-start' }}>
            <Text
              text={data?.status}
              color={data?.textColor}
              size="small"
              textStyle={[
                styles.status,
                {
                  backgroundColor: data?.statusColor
                    ? data?.statusColor
                    : colors.trans.primary10,
                },
              ]}
              numberOfLines={1}
            />
          </View>
          <View style={{ paddingTop: width * 0.02 }}>
            <Text text={renderName} variant="bold" />
            <Text
              text={formatMoney(item?.price)}
              variant="light"
              textStyle={{ marginTop: width * 0.03 }}
            />
          </View>
        </View>
      </View>
      {/* -- END Body */}
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  flex1: {
    flex: 1,
  },
  cardWrapper: {
    borderWidth: 1,
    borderColor: colors.grey.soft,
    borderRadius: width * 0.05,
    padding: width * 0.05,
  },
  header: {
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'flex-start',
    borderBottomColor: colors.grey.soft,
    borderBottomWidth: 1,
    paddingBottom: width * 0.03,
  },
  headIcon: {
    width: width * 0.08,
    height: width * 0.08,
    aspectRatio: 1,
  },
  itemImage: {
    width: width * 0.15,
    height: width * 0.15,
    aspectRatio: 1,
  },
  headBody: {
    flex: 9,
    paddingLeft: width * 0.05,
  },
  body: {
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'flex-start',
    paddingTop: width * 0.03,
  },
  status: {
    paddingVertical: width * 0.01,
    borderRadius: width * 0.01,
    paddingHorizontal: width * 0.02,
  },
});

export default OrderItem;
