import React from 'react';
import {
  ActivityIndicator,
  Image,
  StyleSheet,
  TouchableOpacity,
  View,
} from 'react-native';
import { colors, width } from '../../../constant/theme';
import { Text } from '../../Atoms';

const StoreSmall = ({ loading, data = {}, style, onPress }) => {
  return (
    <TouchableOpacity
      onPress={onPress}
      activeOpacity={0.8}
      style={[styles.cardStall, styles.shadow, style]}
    >
      {loading ? (
        <View style={{ width: '100%' }}>
          <ActivityIndicator color={colors.primary} />
        </View>
      ) : (
        <>
          <Image source={{ uri: data?.image_url }} style={styles.imageStall} />
          <View style={{ width: '80%' }}>
            <Text
              text={data?.name}
              variant="bold"
              textStyle={{ marginBottom: width * 0.01 }}
              numberOfLines={1}
            />
            <Text text={data?.formattedAddress} numberOfLines={3} />
          </View>
        </>
      )}
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  shadow: {
    elevation: 3,
    shadowColor: colors.grey.grey4,
    shadowOffset: { width: 0, height: 0 },
    shadowRadius: 10,
    shadowOpacity: 0.1,
  },
  cardStall: {
    margin: width * 0.05,
    padding: width * 0.03,
    backgroundColor: 'white',
    borderRadius: width * 0.02,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
  },
  imageStall: {
    width: width * 0.14,
    height: width * 0.14,
    aspectRatio: 1,
    borderRadius: width * 0.02,
  },
});

export default StoreSmall;
