import { StyleSheet, View } from 'react-native';
import React, { useEffect, useState } from 'react';
import StackedLabelInput from './StackedLabelInput';
import { Text } from '../../Atoms';
import { height, width } from '../../../constant/theme';

const NoteField = ({ onChangeNote, maxLength = 500 }) => {
  const [note, setNote] = useState('');

  useEffect(() => {
    onChangeNote ? onChangeNote(note) : null;
  }, [note]);

  return (
    <View style={styles.noteWrapper}>
      <StackedLabelInput
        placeholder="Contoh: saya bayar sesuai jumlah"
        label="Tambahan Catatan (Opsional)"
        inputStyle={Boolean(note) ? styles.noteInput : {}}
        value={note}
        onChangeText={(val) => setNote(val)}
        containerStyle={Boolean(note) ? styles.noteContainer : {}}
        multiline={Boolean(note) ? true : false}
        maxLength={maxLength}
      />
      {Boolean(note) ? (
        <View style={styles.noteLength}>
          <Text text={`${note?.split('').length}/${maxLength}`} />
        </View>
      ) : null}
    </View>
  );
};

const styles = StyleSheet.create({
  noteWrapper: { marginTop: width * 0.03 },
  noteInput: {
    maxHeight: height * 0.18,
    textAlign: 'justify',
    textAlignVertical: 'top',
  },
  noteContainer: {
    alignItems: 'flex-start',
    maxHeight: height * 0.15,
    marginBottom: width * 0.01,
  },
  noteLength: {
    width: '100%',
    justifyContent: 'flex-start',
    alignItems: 'flex-end',
    marginVertical: width * 0.05,
  },
});
export default NoteField;
