import React, { useEffect, useState } from 'react';
import { TextInput, TouchableOpacity, View } from 'react-native';
import { Fonts, width } from '../../../constant/theme';
import { Icon } from '../../Atoms';
import { styles } from './input.style';

const TextInputIcon = ({
  inputStyle,
  onChangeText,
  value,
  right,
  style,
  leftIcon = 'search',
  iconColor,
  placeholder = 'Type Here ...',
  ...props
}) => {
  const [tempValue, setTempValue] = useState('');

  useEffect(() => {
    setTempValue(value);
  }, [value]);

  useEffect(() => {
    if (tempValue) {
      onChangeText(tempValue);
    }
  }, [tempValue]);

  return (
    <View style={[styles.content, { paddingHorizontal: width * 0.02 }, style]}>
      <Icon name={leftIcon} size={20} color={iconColor} />
      <TextInput
        {...props}
        style={[
          Fonts.regular,
          Fonts.small,
          styles.formInput,
          { width: '95%' },
          inputStyle,
        ]}
        value={tempValue}
        onChangeText={(val) => {
          setTempValue(val);
        }}
        placeholder={placeholder}
        underlineColorAndroid="transparent"
      />
      {tempValue ? (
        <TouchableOpacity onPress={_clearText}>
          <Icon name="close" size={20} />
        </TouchableOpacity>
      ) : null}
    </View>
  );

  function _clearText() {
    setTempValue('');
  }
};

export default TextInputIcon;
