import React, { useMemo } from 'react';
import {
  FlatList,
  Image,
  StyleSheet,
  TouchableOpacity,
  View,
} from 'react-native';
import { colors, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';

const PickerIconGroup = ({ data = [], onSelect }) => {
  const renderItem = ({ item, index }) => {
    return (
      <TouchableOpacity
        onPress={() => {
          onSelect(item);
        }}
        style={styles.item}
      >
        {item.image ? (
          <View style={{ flex: 1 }}>
            <View style={styles.iconWrapper}>
              <Image source={{ uri: item.image }} style={styles.iconImage} />
            </View>
          </View>
        ) : null}
        <View style={[{ flex: item?.image ? 9 : 1 }, styles.itemList]}>
          <Text text={item?.name} />
          <Icon name="right" color={colors.grey.black} size={20} />
        </View>
      </TouchableOpacity>
    );
  };

  const Content = useMemo(() => {
    return (
      <View style={{ paddingTop: width * 0.03 }}>
        {data.map((el) => {
          return (
            <View style={{ marginBottom: width * 0.05 }}>
              <Text text={el.name} variant="bold" color={colors.grey.grey8} />

              <FlatList
                style={styles.listWrapper}
                data={el?.options}
                keyExtractor={(item, index) => index.toString()}
                renderItem={renderItem}
                nestedScrollEnabled
                showsVerticalScrollIndicator={false}
              />
            </View>
          );
        })}
      </View>
    );
  }, [data]);

  return Content;
};

const styles = StyleSheet.create({
  listWrapper: {
    width: '100%',
  },
  item: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    borderBottomColor: colors.grey.grey8,
    borderBottomWidth: 0.5,
    paddingVertical: width * 0.03,
  },
  iconWrapper: {
    justifyContent: 'center',
    alignItems: 'center',
    width: 30,
    height: 30,
    borderRadius: 15,
    backgroundColor: colors.trans.primary10,
    borderColor: colors.primary,
    borderWidth: 1,
  },
  iconImage: {
    width: '100%',
    height: '100%',
    aspectRatio: 1,
  },
  itemList: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
});

export default PickerIconGroup;
