import PropTypes from 'prop-types';
import React, { useRef } from 'react';
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';

const Content = ({
  children,
  disableKBDismissScroll,
  contentContainerStyle,
  keyboardShouldPersistTaps,
  showsVerticalScrollIndicator,
  ...props
}) => {
  const _scrollView = useRef();

  return (
    <KeyboardAwareScrollView
      ref={_scrollView}
      {...props}
      automaticallyAdjustContentInsets={false}
      contentContainerStyle={[{}, contentContainerStyle]}
      resetScrollToCoords={disableKBDismissScroll ? null : { x: 0, y: 0 }}
      keyboardShouldPersistTaps={keyboardShouldPersistTaps || 'handled'}
      showsVerticalScrollIndicator={showsVerticalScrollIndicator}
    >
      {children}
    </KeyboardAwareScrollView>
  );
};

Content.propTypes = {
  disableKBDismissScroll: PropTypes.bool,
  keyboardShouldPersistTaps: PropTypes.string,
  style: PropTypes.oneOfType([
    PropTypes.object,
    PropTypes.number,
    PropTypes.array,
  ]),
};

export default Content;
