import React, { useMemo } from 'react';
import {
  Image,
  KeyboardAvoidingView,
  Platform,
  StyleSheet,
  View,
} from 'react-native';
import Modal from 'react-native-modal';
import { width } from '../../../constant/theme';
import { Text } from '../../Atoms';
import Button from '../../Molecules/Button/Button';

const ModalBottom = ({
  isVisible,
  title,
  description,
  localImage,
  imageUrl,
  onPress,
  onBackdropPress,
  onBackButtonPress,
  buttonTitle,
  imageStyle,
  bodyStyle,
  descStyle,
  body,
  ...props
}) => {
  const imageSource = localImage ? localImage : { uri: imageUrl };

  const Content = useMemo(() => {
    const ContentWrapper = Platform.OS === 'ios' ? KeyboardAvoidingView : View;
    return (
      <Modal
        onBackdropPress={onBackdropPress}
        onBackButtonPress={onBackButtonPress}
        animationIn="slideInUp"
        isVisible={isVisible}
        swipeDirection={['down']}
        style={styles.wrapper}
        propagateSwipe
        useNativeDriver
        {...props}
      >
        <ContentWrapper behavior="padding">
          <View style={[styles.container, bodyStyle]}>
            <View style={styles.centerTopALign}>
              {imageUrl || localImage ? (
                <Image
                  resizeMode="contain"
                  style={[styles.bottomImage, imageStyle]}
                  source={imageSource}
                />
              ) : null}
              <Text variant="bold" size="large" text={title} />

              {description ? (
                <View style={styles.body}>
                  <Text
                    text={description}
                    textStyle={[styles.descText, descStyle]}
                  />
                </View>
              ) : null}
            </View>
            {body ? body : <Button onPress={onPress} title={buttonTitle} />}
          </View>
        </ContentWrapper>
      </Modal>
    );
  }, [props]);

  return Content;
};

const styles = StyleSheet.create({
  wrapper: {
    justifyContent: 'flex-end',
    margin: 0,
  },
  container: {
    padding: width * 0.05,
    backgroundColor: 'white',
    borderRadius: 4,
    borderColor: 'rgba(0, 0, 0, 0.1)',
    borderTopLeftRadius: 20,
    borderTopRightRadius: 20,
  },
  title: {
    marginBottom: 12,
  },
  body: {
    width: '100%',
    justifyContent: 'center',
    alignSelf: 'center',
  },
  bottomImage: {
    width: width * 0.5,
    height: width * 0.5,
    margin: 10,
    borderRadius: 10,
  },
  descText: {
    lineHeight: Platform.isPad ? 40 : 20,
    textAlign: 'center',
  },
  centerTopALign: {
    width: '100%',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom: width * 0.05,
  },
});

export default ModalBottom;
