import React from 'react';
import { Image, View } from 'react-native';
import Modal from 'react-native-modal';
import { height } from '../../../constant/theme';
import { Text } from '../../Atoms';
import { Button } from '../../Molecules';
import { styles } from './modal.styles';

/**
 * giving props.body would override default button
 */

const ModalCenter = ({
  isVisible,
  modalStyle,
  image,
  description,
  imageStyle,
  title,
  onPress,
  buttonTitle,
  body,
  ...props
}) => {
  return (
    <Modal
      animationIn="slideInUp"
      isVisible={isVisible}
      swipeDirection={['down']}
      hideModalContentWhileAnimating={true}
      useNativeDriver
      {...props}
    >
      <View style={[styles.modalContainer, modalStyle, { padding: 20 }]}>
        {image ? (
          <View style={styles.thumbnailWrapper}>
            <Image
              resizeMode="contain"
              source={image}
              style={imageStyle ? imageStyle : { height: height * 0.25 }}
            />
          </View>
        ) : null}
        <Text
          text={title}
          textStyle={{ marginBottom: 12 }}
          size="extraLarge"
          variant="bold"
        />
        <Text
          text={description}
          textStyle={{ marginBottom: 12, textAlign: 'center', width: '90%' }}
        />
        {onPress && !body ? (
          <Button
            title={buttonTitle ? buttonTitle : 'Mengerti'}
            onPress={onPress}
          />
        ) : null}
        {body}
      </View>
    </Modal>
  );
};

export default ModalCenter;
