import React, { useCallback, useRef, useState } from 'react';
import { Platform, ScrollView, Vibration, View } from 'react-native';
import { width } from '../../../constant/theme';
import CarouselItem from './CarouselItem';
import { styles } from './slider.style';

// TODO: implement auto play interval
const Carousel = ({ data = [], vibrate = false, style, wrapperStyle }) => {
  const ITEM_WIDTH = width * 0.85;
  const scrollRef = useRef(null);

  const [timer, setTimer] = useState(null);
  const [momentumStarted, setMomentumStarted] = useState(false);
  const [isScrollTo, setIsScrollTo] = useState(false);
  const [dragStarted, setDragStarted] = useState(false);

  const onMomentumScrollBegin = () => {
    setMomentumStarted(true);
    timer && clearTimeout(timer);
  };

  const onScrollEndDrag = (e) => {
    setDragStarted(false);
    const _e = { ...e };
    timer && clearTimeout(timer);
    setTimer(
      setTimeout(() => {
        if (!momentumStarted) {
          scrollFix(_e);
        }
      }, 50)
    );
  };

  const onMomentumScrollEnd = (e) => {
    setMomentumStarted(false);

    if (!isScrollTo && !dragStarted) {
      scrollFix(e);
    }
  };

  const onScrollBeginDrag = () => {
    setDragStarted(true);

    if (Platform.OS === 'ios') {
      setIsScrollTo(false);
    }
    timer && clearTimeout(timer);
  };

  const scrollFix = useCallback((e) => {
    let x = 0;
    const w = ITEM_WIDTH;
    const extraMargin = width * 0.05;

    if (e?.nativeEvent?.contentOffset) {
      x = e?.nativeEvent?.contentOffset?.x;
    }
    const selectedIdx = Math.round(x / w);
    const _x = selectedIdx * w;
    if (_x !== x) {
      if (Platform.OS === 'ios') {
        setIsScrollTo(true);
      }
      scrollRef?.current?.scrollTo({ x: _x + extraMargin });
      vibrate && Vibration.vibrate(50);
    }
  }, []);

  if (data.length) {
    return (
      <View style={[styles.sliderWrapper, wrapperStyle]}>
        <ScrollView
          ref={scrollRef}
          horizontal
          showsHorizontalScrollIndicator={false}
          style={style}
          bounces={false}
          onMomentumScrollBegin={(_e) => onMomentumScrollBegin()}
          onMomentumScrollEnd={(e) => onMomentumScrollEnd(e)}
          onScrollBeginDrag={(_e) => onScrollBeginDrag()}
          onScrollEndDrag={(e) => onScrollEndDrag(e)}
        >
          {data?.slice(0, 5).map((item, index) => {
            return <CarouselItem key={index.toString()} item={item} />;
          })}
        </ScrollView>
      </View>
    );
  } else {
    return null;
  }
};

export default Carousel;
