import React, { useCallback, useRef, useState } from 'react';
import {
  Image,
  Platform,
  ScrollView,
  TouchableOpacity,
  View,
} from 'react-native';
import { height, width } from '../../../constant/theme';
import { ImageViewer } from '../../Molecules';

const SliderItem = ({ item, onPress }) => {
  return (
    <TouchableOpacity
      onPress={onPress}
      activeOpacity={0.8}
      style={{ width: width, height: height * 0.35 }}
    >
      <Image
        source={item?.image}
        resizeMode="cover"
        resizeMethod="auto"
        style={{ width: '100%', height: '100%' }}
      />
    </TouchableOpacity>
  );
};

const SliderImage = ({ data = [], style, itemWidth }) => {
  const ITEM_WIDTH = width || itemWidth;
  const scrollRef = useRef(null);

  const [timer, setTimer] = useState(null);
  const [momentumStarted, setMomentumStarted] = useState(false);
  const [isScrollTo, setIsScrollTo] = useState(false);
  const [dragStarted, setDragStarted] = useState(false);
  const [imageData, setImageData] = useState({
    isVisible: false,
    image: null,
  });

  const onMomentumScrollBegin = () => {
    setMomentumStarted(true);
    timer && clearTimeout(timer);
  };

  const onScrollEndDrag = (e) => {
    setDragStarted(false);
    const _e = { ...e };
    timer && clearTimeout(timer);
    setTimer(
      setTimeout(() => {
        if (!momentumStarted) {
          scrollFix(_e);
        }
      }, 50)
    );
  };

  const onMomentumScrollEnd = (e) => {
    setMomentumStarted(false);

    if (!isScrollTo && !dragStarted) {
      scrollFix(e);
    }
  };

  const onScrollBeginDrag = () => {
    setDragStarted(true);

    if (Platform.OS === 'ios') {
      setIsScrollTo(false);
    }
    timer && clearTimeout(timer);
  };

  const scrollFix = useCallback((e) => {
    let x = 0;
    const w = ITEM_WIDTH;

    if (e?.nativeEvent?.contentOffset) {
      x = e?.nativeEvent?.contentOffset?.x;
    }
    const selectedIdx = Math.round(x / w);
    const _x = selectedIdx * w;
    if (_x !== x) {
      if (Platform.OS === 'ios') {
        setIsScrollTo(true);
      }
      scrollRef?.current?.scrollTo({ x: _x });
    }
  }, []);

  return (
    <View style={[{ width, height: height * 0.35 }, style]}>
      <ScrollView
        ref={scrollRef}
        horizontal
        showsHorizontalScrollIndicator={false}
        style={style}
        bounces={false}
        onMomentumScrollBegin={(_e) => onMomentumScrollBegin()}
        onMomentumScrollEnd={(e) => onMomentumScrollEnd(e)}
        onScrollBeginDrag={(_e) => onScrollBeginDrag()}
        onScrollEndDrag={(e) => onScrollEndDrag(e)}
      >
        {data?.map((item, index) => {
          return (
            <SliderItem
              key={index}
              onPress={() => _showImage(item)}
              item={item}
            />
          );
        })}
      </ScrollView>
      <ImageViewer
        isVisible={imageData?.isVisible}
        image={imageData?.image}
        onBackdropPress={_closeModal}
        onBackButtonPress={_closeModal}
        onPress={_closeModal}
      />
    </View>
  );

  function _showImage(item) {
    setImageData({
      isVisible: true,
      image: item?.image,
    });
  }

  function _closeModal() {
    setImageData({
      isVisible: false,
      image: null,
    });
  }
};

export default SliderImage;
