import React, { useState } from 'react';
import { View } from 'react-native';
import Carousel, { Pagination } from 'react-native-snap-carousel';
import { colors, height, width } from '../../../constant/theme';
import CarouselItem from './CarouselItem';
import { styles } from './slider.style';

const SnapCarousel = ({
  data = [],
  contentContainerStyle,
  containerStyle,
  showDot = true,
}) => {
  const [activeSlide, setActiveSlide] = useState(0);

  const renderCarouselItem = ({ item, index }) => {
    return <CarouselItem key={index} item={item} />;
  };
  return (
    <View>
      <Carousel
        enableMomentum={false}
        decelerationRate={0.1}
        activeSlideOffset={1}
        scrollEndDragDebounceValue={0.1}
        removeClippedSubviews={false}
        animationFunc={'timing'}
        animationOptions={{
          friction: 4,
          tension: 40,
          isInteraction: false,
          useNativeDriver: true,
        }}
        containerCustomStyle={[styles.carouselItemContainer, containerStyle]}
        contentContainerCustomStyle={[
          styles.contentBody,
          contentContainerStyle,
        ]}
        data={data}
        enableSnap={true}
        loop={true}
        loopClonesPerSide={data?.length}
        autoplay={true}
        autoplayInterval={7000}
        hasParallaxImages={false}
        renderItem={renderCarouselItem}
        onSnapToItem={(index) => setActiveSlide(index)}
        sliderWidth={width}
        itemWidth={width * 0.85}
        itemHeight={height * 0.2}
      />
      {showDot ? (
        <Pagination
          dotsLength={data?.length}
          activeDotIndex={activeSlide}
          containerStyle={styles.contentBody}
          dotStyle={styles.dotStyle}
          animatedTension={100}
          animatedFriction={100}
          inactiveDotStyle={styles.inactiveDot}
          inactiveDotOpacity={1}
          inactiveDotScale={1}
        />
      ) : null}
    </View>
  );
};

export default SnapCarousel;
